@@ -195,10 +195,14 @@ describe 'tempest' do
         it { should contain_class('openstacklib::openstackclient') }
 
         it 'configure tempest config' do
-          is_expected.to contain_tempest_config('auth/admin_domain_name').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/admin_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('auth/admin_project_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('auth/admin_user_domain_name').with(:value => '<SERVICE DEFAULT>')
+          is_expected.to contain_tempest_config('auth/default_credentials_domain_name').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/admin_password').with_secret( true )
           is_expected.to contain_tempest_config('auth/admin_project_name').with(:value => nil)
           is_expected.to contain_tempest_config('auth/admin_username').with(:value => nil)
+          is_expected.to contain_tempest_config('auth/admin_system').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/tempest_roles').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('auth/use_dynamic_credentials').with(:value => nil)
           is_expected.to contain_tempest_config('dns/nameservers').with(:value => nil)
@@ -215,7 +219,6 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('baremetal/enabled_hardware_types').with(:value => 'ipmi')
           is_expected.to contain_tempest_config('validation/image_ssh_user').with(:value => nil)
           is_expected.to contain_tempest_config('validation/run_validation').with(:value => false)
-          is_expected.to contain_tempest_config('validation/ssh_key_type').with(:value => '<SERVICE DEFAULT>')
           is_expected.to contain_tempest_config('identity/admin_role').with(:value => nil)
           is_expected.to contain_tempest_config('identity/auth_version').with(:value => 'v3')
           is_expected.to contain_tempest_config('identity/alt_password').with(:value => nil)
@@ -232,7 +235,7 @@ describe 'tempest' do
           is_expected.to contain_tempest_config('identity/disable_ssl_certificate_validation').with(:value => nil)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v2').with(:value => false)
           is_expected.to contain_tempest_config('identity-feature-enabled/api_v3').with(:value => true)
-          is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => false)
+          is_expected.to contain_tempest_config('image-feature-enabled/api_v1').with(:value => true)
           is_expected.to contain_tempest_config('image-feature-enabled/api_v2').with(:value => true)
           is_expected.to contain_tempest_config('l2gw/l2gw_switch').with(:value => nil)
           is_expected.to contain_tempest_config('network-feature-enabled/api_extensions').with(:value => nil)
